======
region
======

The ``region`` module provides a polygon filling algorithm
used by ``skymatch`` to create data masks.

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. currentmodule:: jwst.skymatch.region

.. automodule:: jwst.skymatch.region
   :members:
   :undoc-members:
